@@ -10,8 +10,10 @@
 #include <QObject>
 #include <QSize>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
+struct org_kde_plasma_activation_feedback;
+struct org_kde_plasma_activation;
 struct org_kde_plasma_window_management;
 struct org_kde_plasma_window;
 
@@ -20,6 +22,8 @@ namespace KWayland
 namespace Client
 {
 class EventQueue;
+class Output;
+class PlasmaActivationFeedback;
 class PlasmaWindow;
 class PlasmaWindowModel;
 class Surface;
@@ -59,7 +63,7 @@ class KWAYLANDCLIENT_EXPORT PlasmaWindowManagement : public QObject
     Q_OBJECT
 public:
     explicit PlasmaWindowManagement(QObject *parent = nullptr);
-    virtual ~PlasmaWindowManagement();
+    ~PlasmaWindowManagement() override;
 
     /**
      * @returns @c true if managing a org_kde_plasma_window_management.
@@ -155,22 +159,12 @@ public:
      **/
     PlasmaWindowModel *createWindowModel();
 
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
-    /**
-     * @returns windows stacking order
-     *
-     * @deprecated Since 5.73, use stackingOrderUuids()
-     */
-    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::stackingOrderUuids()")
-    QVector<quint32> stackingOrder() const;
-#endif
-
     /**
      * @returns windows stacking order
      *
      * @since 5.73
      */
-    QVector<QByteArray> stackingOrderUuids() const;
+    QList<QByteArray> stackingOrderUuids() const;
 
 Q_SIGNALS:
     /**
@@ -208,24 +202,16 @@ Q_SIGNALS:
      **/
     void removed();
 
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
-    /**
-     * The stacking order changed
-     * @since 5.70
-     * @deprecated Since 5.73, use stackingOrderUuidsChanged()
-     **/
-    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::stackingOrderUuidsChanged()")
-    void stackingOrderChanged();
-#endif
-
     /**
      * The stacking order uuids changed
      * @since 5.73
      **/
     void stackingOrderUuidsChanged();
 
-private:
+public:
     class Private;
+
+private:
     QScopedPointer<Private> d;
 };
 
@@ -247,7 +233,7 @@ class KWAYLANDCLIENT_EXPORT PlasmaWindow : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~PlasmaWindow();
+    ~PlasmaWindow() override;
 
     /**
      * Releases the org_kde_plasma_window interface.
@@ -290,15 +276,6 @@ public:
      * @see appIdChanged
      **/
     QString appId() const;
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
-    /**
-     * @returns the id of the virtual desktop this PlasmaWindow is on
-     * @see virtualDesktopChanged
-     * @deprecated: Since 5.52, use plasmaVirtualDesktops instead
-     **/
-    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 52, "Use PlasmaWindow::plasmaVirtualDesktops()")
-    quint32 virtualDesktop() const;
-#endif
     /**
      * @returns Whether the window is currently the active Window.
      * @see activeChanged
@@ -412,6 +389,12 @@ public:
      * @since 5.35
      */
     quint32 pid() const;
+    /**
+     * @returns The X11 resource name for this window.
+     * This is only set for X11 windows.
+     * @since 5.94
+     */
+    QString resourceName() const;
 
     /**
      * Requests to activate the window.
@@ -431,14 +414,6 @@ public:
      * @since 5.22
      */
     void requestResize();
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
-    /**
-     * Requests to send the window to virtual @p desktop.
-     * @deprecated: Since 5.52, use requestEnterVirtualDesktop instead
-     **/
-    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 52, "Use PlasmaWindow::requestEnterVirtualDesktop(const QString &)")
-    void requestVirtualDesktop(quint32 desktop);
-#endif
 
     /**
      * Requests the window at this model row index have its keep above state toggled.
@@ -462,6 +437,12 @@ public:
      */
     void requestToggleMaximized();
 
+    /**
+     * Requests the window at this model row index have its fullscreen state toggled.
+     * @since 6.0
+     */
+    void requestToggleFullscreen();
+
     /**
      * Sets the geometry of the taskbar entry for this window
      * relative to a panel in particular
@@ -481,18 +462,6 @@ public:
      */
     void requestToggleShaded();
 
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
-    /**
-     * An internal window identifier.
-     * This is not a global window identifier.
-     * This identifier does not correspond to QWindow::winId in any way.
-     *
-     * @deprecated Since 5.73, use uuid(const QString &) instead
-     */
-    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::uuid(const QString &)")
-    quint32 internalId() const;
-#endif
-
     /**
      * A unique identifier for the window
      *
@@ -596,6 +565,20 @@ public:
      */
     QString applicationMenuObjectPath() const;
 
+    /**
+     * Sends the current window to @p output
+     *
+     * @since 5.86
+     */
+    void sendToOutput(KWayland::Client::Output *output) const;
+
+    /**
+     * @returns The client geometry (i.e. without window borders) in absolute coordinates.
+     * @see clientGeometryChanged
+     * @since 6.2
+     **/
+    QRect clientGeometry() const;
+
 Q_SIGNALS:
     /**
      * The window title changed.
@@ -607,17 +590,6 @@ Q_SIGNALS:
      * @see appId
      **/
     void appIdChanged();
-#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
-    /**
-     * The virtual desktop changed.
-     * @deprecated Since 5.52, use plasmaVirtualDesktopEntered and plasmaVirtualDesktopLeft instead
-     **/
-    KWAYLANDCLIENT_DEPRECATED_VERSION(
-        5,
-        52,
-        "Use PlasmaWindow::plasmaVirtualDesktopEntered(const QString &) and PlasmaWindow::plasmaVirtualDesktopLeft(const QString &)")
-    void virtualDesktopChanged();
-#endif
     /**
      * The window became active or inactive.
      * @see isActive
@@ -742,6 +714,13 @@ Q_SIGNALS:
      **/
     void geometryChanged();
 
+    /**
+     * This signal is emitted whenever the resource name changes.
+     * @see resourceName
+     * @since 5.94
+     **/
+    void resourceNameChanged();
+
     /**
      * This signal is emitted when the window has entered a new virtual desktop.
      * The window can be on more than one desktop, or none: then is considered on all of them.
@@ -780,13 +759,141 @@ Q_SIGNALS:
      **/
     void applicationMenuChanged();
 
+    /**
+     * This signal is emitted whenever the client geometry changes.
+     * @see clientGeometry
+     * @since 6.2
+     **/
+    void clientGeometryChanged();
+
 private:
     friend class PlasmaWindowManagement;
-    explicit PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *dataOffer, quint32 internalId, const char *uuid);
+    explicit PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *activation, quint32 internalId, const char *uuid);
     class Private;
     QScopedPointer<Private> d;
 };
 
+/**
+ * @since 5.86
+ */
+class KWAYLANDCLIENT_EXPORT PlasmaActivation : public QObject
+{
+    Q_OBJECT
+public:
+    ~PlasmaActivation() override;
+
+Q_SIGNALS:
+    /**
+     * Informs about which application this activation is representing
+     *
+     * The @p appId can be used to infer how to decorate this activation.
+     */
+    void applicationId(const QString &appId);
+
+    /**
+     * Notifies that the activation is done with.
+     *
+     * It might happen either because it's over or because it timed out.
+     */
+    void finished();
+
+private:
+    friend class PlasmaActivationFeedback;
+    explicit PlasmaActivation(PlasmaActivationFeedback *parent, org_kde_plasma_activation *activation);
+    class Private;
+    QScopedPointer<Private> d;
+};
+
+/**
+ * @since 5.86
+ */
+class KWAYLANDCLIENT_EXPORT PlasmaActivationFeedback : public QObject
+{
+    Q_OBJECT
+
+public:
+    explicit PlasmaActivationFeedback(QObject *parent = nullptr);
+    ~PlasmaActivationFeedback() override;
+
+    /**
+     * @returns @c true if managing a org_kde_plasma_activation_feedback.
+     **/
+    bool isValid() const;
+
+    /**
+     * Releases the org_kde_plasma_activation_feedback interface.
+     * After the interface has been released the PlasmaActivationFeedback instance is no
+     * longer valid and can be setup with another org_kde_plasma_activation_feedback interface.
+     *
+     * Right before the interface is released the signal interfaceAboutToBeReleased is emitted.
+     * @see interfaceAboutToBeReleased
+     **/
+    void release();
+
+    /**
+     * Destroys the data held by this PlasmaActivationFeedback.
+     * This method is supposed to be used when the connection to the Wayland
+     * server goes away. Once the connection becomes invalid, it's not
+     * possible to call release anymore as that calls into the Wayland
+     * connection and the call would fail. This method cleans up the data, so
+     * that the instance can be deleted or set up to a new org_kde_plasma_activation_feedback interface
+     * once there is a new connection available.
+     *
+     * This method is automatically invoked when the Registry which created this
+     * PlasmaActivationFeedback gets destroyed.
+     *
+     * Right before the data is destroyed, the signal interfaceAboutToBeDestroyed is emitted.
+     *
+     * @see release
+     * @see interfaceAboutToBeDestroyed
+     **/
+    void destroy();
+
+    /**
+     * Setup this PlasmaActivationFeedback to manage the @p manager.
+     * When using Registry::createPlasmaActivationFeedback there is no need to call this
+     * method.
+     **/
+    void setup(org_kde_plasma_activation_feedback *manager);
+
+    /**
+     * Sets the @p queue to use for creating a PlasmaActivationFeedback.
+     **/
+    void setEventQueue(EventQueue *queue);
+
+    /**
+     * @returns The event queue to use for creating a PlasmaActivationFeedback.
+     **/
+    EventQueue *eventQueue();
+
+    operator org_kde_plasma_activation_feedback *();
+    operator org_kde_plasma_activation_feedback *() const;
+
+Q_SIGNALS:
+    /**
+     * This signal is emitted right before the interface is released.
+     **/
+    void interfaceAboutToBeReleased();
+
+    /**
+     * This signal is emitted right before the data is destroyed.
+     **/
+    void interfaceAboutToBeDestroyed();
+
+    /**
+     * The corresponding global for this interface on the Registry got removed.
+     *
+     * This signal gets only emitted if the Compositor got created by
+     * Registry::createPlasmaActivationFeedback
+     **/
+    void removed();
+
+    void activation(KWayland::Client::PlasmaActivation *activation);
+
+private:
+    class Private;
+    QScopedPointer<Private> d;
+};
 }
 }
 
